==> geolatte-geom-0.13-sources.jar: org/geolatte/geom/codec/WkbEncoder.java <==
/*
 * This file is part of the GeoLatte project.
 *
 *     GeoLatte is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU Lesser General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     GeoLatte is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU Lesser General Public License for more details.
 *
 *     You should have received a copy of the GNU Lesser General Public License
 *     along with GeoLatte.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Copyright (C) 2010 - 2012 and Ownership of code is shared by:
 * Qmino bvba - Romeinsestraat 18 - 3001 Heverlee  (http://www.qmino.com)
 * Geovise bvba - Generaal Eisenhowerlei 9 - 2140 Antwerpen (http://www.geovise.com)
 */

package org.geolatte.geom.codec;

import org.geolatte.geom.ByteBuffer;
import org.geolatte.geom.ByteOrder;
import org.geolatte.geom.Geometry;

/**
 * An encoder for WKB (Well-Known Binary) encoded <code>Geometries</code>.
 *
 * <p>In general <code>WkbEncoder</code> implementations are not be thread-safe.</p>
 *
 * @author Karel Maesen, Geovise BVBA
 *         creation-date: 9/29/12
 */
public interface WkbEncoder {
    /**
     * Encodes a <code>Geometry</code> to its WKB representation
     * @param geometry the geometry to encode
     * @param byteOrder the bye-order for the WKB representation
     * @return a ByteBuffer containing the binary WKB representation of the specified geometry using the specified byte-order
     */
    ByteBuffer encode(Geometry geometry, ByteOrder byteOrder);
}

==> geolatte-geom-1.3.0-sources.jar: org/geolatte/geom/codec/WkbEncoder.java <==
/*
 * This file is part of the GeoLatte project.
 *
 *     GeoLatte is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU Lesser General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     GeoLatte is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU Lesser General Public License for more details.
 *
 *     You should have received a copy of the GNU Lesser General Public License
 *     along with GeoLatte.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Copyright (C) 2010 - 2012 and Ownership of code is shared by:
 * Qmino bvba - Romeinsestraat 18 - 3001 Heverlee  (http://www.qmino.com)
 * Geovise bvba - Generaal Eisenhowerlei 9 - 2140 Antwerpen (http://www.geovise.com)
 */

package org.geolatte.geom.codec;

import org.geolatte.geom.ByteBuffer;
import org.geolatte.geom.ByteOrder;
import org.geolatte.geom.Geometry;
import org.geolatte.geom.Position;

/**
 * An encoder for WKB (Well-Known Binary) encoded <code>Geometries</code>.
 *
 * <p>In general <code>WkbEncoder</code> implementations are not be thread-safe.</p>
 *
 * @author Karel Maesen, Geovise BVBA
 *         creation-date: 9/29/12
 */
public interface WkbEncoder {
    /**
     * Encodes a <code>Geometry</code> to its WKB representation
     * @param geometry the geometry to encode
     * @param byteOrder the bye-order for the WKB representation
     * @return a ByteBuffer containing the binary WKB representation of the specified geometry using the specified byte-order
     */
    <P extends Position> ByteBuffer encode(Geometry<P> geometry, ByteOrder byteOrder);
}
